@@ -44,7 +44,11 @@ class _IntrospectorInterface(ABC):
         attrs = [
             attr for attr in dir(
                 self.schema
-            ) if not is_dunder(attr) and attr not in remove_keys
+            ) if not is_dunder(
+                attr
+            ) and not callable(
+                getattr(self.schema, attr)
+            ) and attr not in remove_keys
         ]
         return attrs
 
